# Copyright 2021 DeepMind Technologies Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Implementation of the XManager Launch API within the local scheduler."""

from xmanager.cloud import vertex
from xmanager.xm_local import experiment
from xmanager.xm_local.executors import *

create_experiment = experiment.create_experiment
get_experiment = experiment.get_experiment
list_experiments = experiment.list_experiments
vertex_client = vertex.client
